library(psych)
library(tidyverse)
library(igraph)

#input data
type=read.csv('F:/drawpicture/input/type2.csv')
class(type$node)
type$node=as.character(type$node)
class(type$type)
data1=read.csv('F:/drawpicture/input/net-m5-m8.csv')

wmfunc=function(in1){
  cor.data=in1
  c(as.character(cor.data$node1),as.character(cor.data$node2)) %>%
    as_tibble() %>%
    group_by(value) %>%
    summarize(n=n()) -> vertices
  colnames(vertices) <- c("node", "n")
  vertices %>%
    left_join(type,by="node") -> vertices 
  vertices$type = factor(vertices$type,levels = unique(vertices$type))
  vertices = arrange(vertices,type)
  
  g <- graph_from_data_frame(cor.data, vertices = vertices, directed = FALSE )
  g <- igraph::simplify(g,remove.multiple = TRUE,remove.loops = TRUE,edge.attr.comb = "first")
  is.simple(g)
  E(g)$weight <- 1
  is.weighted(g)
  vcount(g) 
  ecount(g) 
  V(g)$point.col <- V(g)$type
  
  return(g)
}

cor.data1=data1[1:234,]
cor.data2=data1[235:276,]
cor.data3=data1[277:408,]
cor.data4=data1[409:642,]
cor.data5=data1[643:742,]
cor.data6=data1[743:852,]
xx1=wmfunc(cor.data1)
xx2=wmfunc(cor.data2)
xx3=wmfunc(cor.data3)
xx4=wmfunc(cor.data4)
xx5=wmfunc(cor.data5)
xx6=wmfunc(cor.data6)

#draw picture
png(filename = 'F:/drawpicture/output/socialnetwork-month5.png',width = 1200,height = 1000)
wmcolor=c('#009E73','#D55E00','cyan','black','yellow','blue','orange')
cex1=2.5
cex2=2.5
lwd1=2.5

layout(matrix(c(1,1,1,2,3,4,5,6,7),3,3,byrow = T),heights = c(1,2.5,2.5))
par(mar=c(0,1.5,0,4),cex=1)
plot(-0.1,xlim=c(0.6,1.2),ylim=c(-0.2,-0.03),type = "n",bty='n',yaxt='n',xaxt='n',xlab='',ylab = '')
legend(0.66,0,xpd=TRUE,horiz = T,bty='n',box.lty=0,pch=15,text.width=0.2,
       legend=c('mainly bird','mainly insect','mainly rain'), 
       col = c('#009E73','#D55E00','cyan'),cex = cex1)
legend(0.66,-0.05,xpd=TRUE,horiz = T,bty='n',box.lty=0,pch=15,text.width=0.2,
       legend=c('no obvious biophony','bird and insect'), 
       col = c('black','yellow'),cex = cex1)
legend(0.66,-0.1,xpd=TRUE,horiz = T,bty='n',box.lty=0,pch=15,text.width=0.2,
       legend=c('bird and rain','biophony and anthropophony'), 
       col = c('blue','orange'),cex = cex1)
text(0.58, -0.1, col='black',"May",cex = cex1,adj = 0)

size0=1.5
par(mar=c(0.1,0.1,0.1,0.1),cex=1)
xx0=xx1
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)

par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site1",cex = cex1,adj = 0)

xx0=xx2
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site2",cex = cex1,adj = 0)

xx0=xx3
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site3",cex = cex1,adj = 0)

xx0=xx4
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site4",cex = cex1,adj = 0)

xx0=xx5
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site5",cex = cex1,adj = 0)


xx0=xx6
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site6",cex = cex1,adj = 0)

dev.off()


#
cor.data1=data1[853:943,]
cor.data2=data1[944:979,]
cor.data3=data1[980:1029,]
cor.data4=data1[1030:1077,]
cor.data5=data1[1078:1125,]
cor.data6=data1[1126:1181,]
xx1=wmfunc(cor.data1)
xx2=wmfunc(cor.data2)
xx3=wmfunc(cor.data3)
xx4=wmfunc(cor.data4)
xx5=wmfunc(cor.data5)
xx6=wmfunc(cor.data6)
#draw picture
png(filename = 'F:/drawpicture/output/socialnetwork-month8.png',width = 1200,height = 1000)
wmcolor=c('#009E73','#D55E00','cyan','black','yellow','blue','orange')
cex1=2.5
cex2=2.5
lwd1=2.5

layout(matrix(c(1,1,1,2,3,4,5,6,7),3,3,byrow = T),heights = c(1,2.5,2.5))
par(mar=c(0,1.5,0,4),cex=1)
plot(-0.1,xlim=c(0.6,1.2),ylim=c(-0.2,-0.03),type = "n",bty='n',yaxt='n',xaxt='n',xlab='',ylab = '')
legend(0.66,0,xpd=TRUE,horiz = T,bty='n',box.lty=0,pch=15,text.width=0.2,
       legend=c('mainly bird','mainly insect','mainly rain'), 
       col = c('#009E73','#D55E00','cyan'),cex = cex1)
legend(0.66,-0.05,xpd=TRUE,horiz = T,bty='n',box.lty=0,pch=15,text.width=0.2,
       legend=c('no obvious biophony','bird and insect'), 
       col = c('black','yellow'),cex = cex1)
legend(0.66,-0.1,xpd=TRUE,horiz = T,bty='n',box.lty=0,pch=15,text.width=0.2,
       legend=c('bird and rain','biophony and anthropophony'), 
       col = c('blue','orange'),cex = cex1)
text(0.58, -0.1, col='black',"August",cex = cex1,adj = 0)

size0=2
par(mar=c(0.1,0.1,0.1,0.1),cex=1)
xx0=xx1
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)

par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site1",cex = cex1,adj = 0)

xx0=xx2
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site2",cex = cex1,adj = 0)

xx0=xx3
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site3",cex = cex1,adj = 0)

xx0=xx4
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site4",cex = cex1,adj = 0)

xx0=xx5
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site5",cex = cex1,adj = 0)


xx0=xx6
set.seed(123)
plot.igraph(xx0, layout=layout_with_fr(xx0),
            vertex.label.col="#D55E00",
            vertex.frame.color ="black",
            vertex.color=V(xx0)$point.col,
            vertex.size=(V(xx0)$n)*size0,
            vertex.label=xx0$name,
            vertex.label.cex=cex1,
            vertex.label.color='black',
            vertex.label.family='Arial'
)
par(new=T)
plot(1,xlim=c(1,2),ylim=c(1,2),yaxt='n',xaxt='n',xlab='',ylab = '',type = 'n',bty='n')
rect(0.98,0.98,2.02,2.02,lwd=lwd1)
text(1.02, 1.95, col='black',"site6",cex = cex1,adj = 0)

dev.off()

